#
# spec file for package pixelorama
#
# Copyright (c) 2023-2025 cunix
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define _buildshell /bin/bash
%define nameupper Pixelorama

Name:           pixelorama
Version:        1.0.5
Release:        2.2
Summary:        2D sprite editor
License:        MIT
Group:          Productivity/Graphics/Bitmap Editors
URL:            https://github.com/Orama-Interactive/Pixelorama
Source0:        https://codeload.github.com/Orama-Interactive/%{nameupper}/tar.gz/refs/tags/v%{version}#/%{name}-%{version}.tar.gz
BuildRequires:  fdupes
BuildRequires:  godot >= 4.3
BuildRequires:  godot-runner >= 4.3
BuildRequires:  vendored_licenses_packager
# currently no godot binary
ExcludeArch:    %arm
# build fails: Segmentation fault godot --headless --verbose --import
ExcludeArch:    %ix86
ExcludeArch:    %power64

%description
Graphical tool based on the Godot Engine to create and edit
animated pixel art, game graphics, tiles and many kinds of pixel art

%prep
%autosetup -n %{nameupper}-%{version}
template_dir=$(godot-runner --version | grep --extended-regexp --only-matching --regexp ^\([0-9]+\\.\)+stable -)
r=$(echo $?)
if [[ x"$template_dir" != x ]]
  then
    if [[ $r -eq 0 ]]
      then echo godot version found: $template_dir
      else echo regex failure; exit 1
    fi
  else echo template_dir empty; exit 1
fi
%ifarch %{arm} %{arm64}
template_name=linux_release.arm%{__isa_bits}
%elifarch %{ix86} %{x86_64}
template_name=linux_release.x86_%{__isa_bits}
%else
template_name=linux_release.%{_arch}
%endif
target_dir=$HOME/.local/share/godot/export_templates/$template_dir
target_file_path=$target_dir/$template_name
mkdir -p $target_dir
cp %{_bindir}/godot-runner $target_file_path
sed -i "s/binary_format\/embed_pck=false/binary_format\/embed_pck=true/" ./export_presets.cfg
cp addons/README.md addons_README.md
cp Misc/Linux/com.orama_interactive.%{nameupper}.desktop com.orama_interactive.%{nameupper}.desktop
rm pixelorama_data/.gdignore
mkdir binary
%vendored_licenses_packager_prep addons

%build
%ifarch %{arm} %{arm64}
export_name="Linux ARM%{__isa_bits}"
%else
export_name="Linux %{__isa_bits}-bit"
%endif

godot --headless --verbose --import
godot --headless --verbose --export-release "$export_name" binary/%{name}

%install
v=('Brushes' 'Palettes' 'Patterns')
for d in "${v[@]}"
  do
    echo install "$d"
    install -D -d -m 0755 %{buildroot}%{_datadir}/%{name}/$d
    cp -R pixelorama_data/$d/* %{buildroot}%{_datadir}/%{name}/$d/
  done
install -D -p -m 0755 binary/%{name} %{buildroot}%{_bindir}/%{name}
install -D -p -m 0644 assets/graphics/icons/icon.png %{buildroot}%{_datadir}/icons/hicolor/256x256/apps/%{name}.png
install -D -p -m 0644 Misc/Linux/com.orama_interactive.%{nameupper}.desktop %{buildroot}%{_datadir}/applications/com.orama_interactive.%{nameupper}.desktop
install -D -p -m 0644 Misc/Linux/com.orama_interactive.%{nameupper}.appdata.xml  %{buildroot}%{_datadir}/metainfo/com.orama_interactive.%{nameupper}.appdata.xml
%vendored_licenses_packager_install
%fdupes -s %{buildroot}/%{_prefix}

%files
%license LICENSE addons_README.md
%doc CHANGELOG.md CONTRIBUTING.md README.md
%dir %{_datadir}/icons/hicolor
%dir %{_datadir}/icons/hicolor/256x256
%dir %{_datadir}/icons/hicolor/256x256/apps
%{_bindir}/%{name}
%{_datadir}/%{name}
%{_datadir}/metainfo/com.orama_interactive.%{nameupper}.appdata.xml
%{_datadir}/applications/com.orama_interactive.%{nameupper}.desktop
%{_datadir}/icons/hicolor/256x256/apps/%{name}.png
%vendored_licenses_packager_files

%changelog
* Sun Feb 16 2025 cunix@mail.de
- restored source uri
- disabled i586 builds
* Thu Feb  6 2025 Jorik Cronenberg <jorik.cronenberg@suse.com>
- Update to 1.0.5
  Some noteworthy changes from 1.0
  * The config file has been renamed from "cache.ini" to
    "config.ini". This effectively means that preferences edited in
    v0.x will not be automatically be carried over to v1.0.
  * The file format of pxo files has been changed. Pxo files are
    now zip files in disguise.
  * Similarly, the file format of Pixelorama's palette files has
    been changed from .tres back to .json as they used to be in the
    past. This change had to happen due to security concerns
    regarding Godot's resource files.
  Changes from 1.0.5:
  Added:
  * Add density to the square & circle brushes. 100%% density means
    that the brush gets completely drawn. Anything less leaves gaps
    inside the brush, acting like a spray tool.
  * Selection expanding, shrinking and borders have been added as
    options in the Select menu.
  * Mouse buttons can now be used as menu shortcuts. #1070
  * Added confirm and cancel buttons in the selection tool options
    to confirm/cancel an active transformation.
  * OKHSL Lightness sorting in palettes has been implemented. #1126
  Changed:
  * The brush size no longer changes by Control + Mouse
    Wheel when resizing the timeline cels or the palette swatches.
  * Improved the UI of the Tile Mode Offsets dialog and added an
    "Isometric" preset button.
  * The Recorder panel now automatically records for the current
    project. This also allows for multiple projects to be recorded
    at the same time.
  Fixed:
  * Opening the Tile Mode Offsets dialog no longer crashes the
    application.
  * Panels no longer get scrolled when using the mouse wheel over a
    slider.
  * Fixed layer effect slider values being rounded to the nearest
    integer.
  * Fixed memory leak where the project remained referenced by a
    drawing tool, even when its tab was closed.
  * Fixed memory leak where the first project remained forever
    references in memory by the Recorder panel.
  * Slightly optimize circle brushes by only calling the ellipse
    algorithms once while drawing
  Removed:
  * The Recorder panel has been removed from the Web version. It
    wasn't functional anyway in a way that was useful, and it's
    unsure if we can find a way to make it work.
  For a full list of changes since the last release see the github
  release notes at
  https://github.com/Orama-Interactive/Pixelorama/releases
* Mon Apr 22 2024 cunix@mail.de
- Update to 0.11.4
  * Exporting palettes to png files is now possible
  * When quitting, multiple save confirmation dialogs now appear,
    each for every project that has changes
  * Loop through frames when clicking on go to
    previous/next frame buttons on the timeline
  * Make cloned frames only select a cel if its
    corresponding original cel was selected as well
  * All of the timeline buttons now have the same size
  * Attempting to load an invalid pxo file no longer crashes the application
  * Random brushes now work again
* Wed Nov  1 2023 cunix@mail.de
- Update to 0.11.3
  * When deleting a palette, a confirmation window now appears that
    lets users either delete the palette permanently, move it to trash
    or cancel
  * Fixed undo/redo history not working when the tool changes
  * Pixelorama no longer closes when the project fails to be saved
    if "Save & Exit" is selected
  * Projects with 3D cels saved in 1.x can now be opened in 0.11.3
* Tue Sep 19 2023 cunix@mail.de
- initial package version 0.11.2
